config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/DIR_COLORS.new

( cd usr/man/man1 ; rm -rf ginstall.1.gz )
( cd usr/man/man1 ; ln -sf install.1.gz ginstall.1.gz )
( cd usr/bin ; rm -rf sha1sum )
( cd usr/bin ; ln -sf ../../bin/sha1sum sha1sum )
( cd usr/bin ; rm -rf sha256sum )
( cd usr/bin ; ln -sf ../../bin/sha256sum sha256sum )
( cd usr/bin ; rm -rf sha224sum )
( cd usr/bin ; ln -sf ../../bin/sha224sum sha224sum )
( cd usr/bin ; rm -rf join )
( cd usr/bin ; ln -sf ../../bin/join join )
( cd usr/bin ; rm -rf stat )
( cd usr/bin ; ln -sf ../../bin/stat stat )
( cd usr/bin ; rm -rf cp )
( cd usr/bin ; ln -sf ../../bin/cp cp )
( cd usr/bin ; rm -rf split )
( cd usr/bin ; ln -sf ../../bin/split split )
( cd usr/bin ; rm -rf chroot )
( cd usr/bin ; ln -sf ../../bin/chroot chroot )
( cd usr/bin ; rm -rf [ )
( cd usr/bin ; ln -sf ../../bin/[ [ )
( cd usr/bin ; rm -rf hostid )
( cd usr/bin ; ln -sf ../../bin/hostid hostid )
( cd usr/bin ; rm -rf pwd )
( cd usr/bin ; ln -sf ../../bin/pwd pwd )
( cd usr/bin ; rm -rf touch )
( cd usr/bin ; ln -sf ../../bin/touch touch )
( cd usr/bin ; rm -rf false )
( cd usr/bin ; ln -sf ../../bin/false false )
( cd usr/bin ; rm -rf mkfifo )
( cd usr/bin ; ln -sf ../../bin/mkfifo mkfifo )
( cd usr/bin ; rm -rf chown )
( cd usr/bin ; ln -sf ../../bin/chown chown )
( cd usr/bin ; rm -rf users )
( cd usr/bin ; ln -sf ../../bin/users users )
( cd usr/bin ; rm -rf cksum )
( cd usr/bin ; ln -sf ../../bin/cksum cksum )
( cd usr/bin ; rm -rf shuf )
( cd usr/bin ; ln -sf ../../bin/shuf shuf )
( cd usr/bin ; rm -rf realpath )
( cd usr/bin ; ln -sf ../../bin/realpath realpath )
( cd usr/bin ; rm -rf true )
( cd usr/bin ; ln -sf ../../bin/true true )
( cd usr/bin ; rm -rf pinky )
( cd usr/bin ; ln -sf ../../bin/pinky pinky )
( cd usr/bin ; rm -rf rm )
( cd usr/bin ; ln -sf ../../bin/rm rm )
( cd usr/bin ; rm -rf ls )
( cd usr/bin ; ln -sf ../../bin/ls ls )
( cd usr/bin ; rm -rf fmt )
( cd usr/bin ; ln -sf ../../bin/fmt fmt )
( cd usr/bin ; rm -rf yes )
( cd usr/bin ; ln -sf ../../bin/yes yes )
( cd usr/bin ; rm -rf tee )
( cd usr/bin ; ln -sf ../../bin/tee tee )
( cd usr/bin ; rm -rf runcon )
( cd usr/bin ; ln -sf ../../bin/runcon runcon )
( cd usr/bin ; rm -rf readlink )
( cd usr/bin ; ln -sf ../../bin/readlink readlink )
( cd usr/bin ; rm -rf csplit )
( cd usr/bin ; ln -sf ../../bin/csplit csplit )
( cd usr/bin ; rm -rf uname )
( cd usr/bin ; ln -sf ../../bin/uname uname )
( cd usr/bin ; rm -rf dir )
( cd usr/bin ; ln -sf ../../bin/dir dir )
( cd usr/bin ; rm -rf unlink )
( cd usr/bin ; ln -sf ../../bin/unlink unlink )
( cd usr/bin ; rm -rf factor )
( cd usr/bin ; ln -sf ../../bin/factor factor )
( cd usr/bin ; rm -rf rmdir )
( cd usr/bin ; ln -sf ../../bin/rmdir rmdir )
( cd usr/bin ; rm -rf echo )
( cd usr/bin ; ln -sf ../../bin/echo echo )
( cd usr/bin ; rm -rf seq )
( cd usr/bin ; ln -sf ../../bin/seq seq )
( cd usr/bin ; rm -rf uniq )
( cd usr/bin ; ln -sf ../../bin/uniq uniq )
( cd usr/bin ; rm -rf vdir )
( cd usr/bin ; ln -sf ../../bin/vdir vdir )
( cd usr/bin ; rm -rf md5sum )
( cd usr/bin ; ln -sf ../../bin/md5sum md5sum )
( cd usr/bin ; rm -rf du )
( cd usr/bin ; ln -sf ../../bin/du du )
( cd usr/bin ; rm -rf printf )
( cd usr/bin ; ln -sf ../../bin/printf printf )
( cd usr/bin ; rm -rf chgrp )
( cd usr/bin ; ln -sf ../../bin/chgrp chgrp )
( cd usr/bin ; rm -rf head )
( cd usr/bin ; ln -sf ../../bin/head head )
( cd usr/bin ; rm -rf pr )
( cd usr/bin ; ln -sf ../../bin/pr pr )
( cd usr/bin ; rm -rf test )
( cd usr/bin ; ln -sf ../../bin/test test )
( cd usr/bin ; rm -rf nproc )
( cd usr/bin ; ln -sf ../../bin/nproc nproc )
( cd usr/bin ; rm -rf date )
( cd usr/bin ; ln -sf ../../bin/date date )
( cd usr/bin ; rm -rf cut )
( cd usr/bin ; ln -sf ../../bin/cut cut )
( cd usr/bin ; rm -rf expand )
( cd usr/bin ; ln -sf ../../bin/expand expand )
( cd usr/bin ; rm -rf truncate )
( cd usr/bin ; ln -sf ../../bin/truncate truncate )
( cd usr/bin ; rm -rf basename )
( cd usr/bin ; ln -sf ../../bin/basename basename )
( cd usr/bin ; rm -rf expr )
( cd usr/bin ; ln -sf ../../bin/expr expr )
( cd usr/bin ; rm -rf pathchk )
( cd usr/bin ; ln -sf ../../bin/pathchk pathchk )
( cd usr/bin ; rm -rf install )
( cd usr/bin ; ln -sf ../../bin/install install )
( cd usr/bin ; rm -rf printenv )
( cd usr/bin ; ln -sf ../../bin/printenv printenv )
( cd usr/bin ; rm -rf chmod )
( cd usr/bin ; ln -sf ../../bin/chmod chmod )
( cd usr/bin ; rm -rf logname )
( cd usr/bin ; ln -sf ../../bin/logname logname )
( cd usr/bin ; rm -rf chcon )
( cd usr/bin ; ln -sf ../../bin/chcon chcon )
( cd usr/bin ; rm -rf nl )
( cd usr/bin ; ln -sf ../../bin/nl nl )
( cd usr/bin ; rm -rf mkdir )
( cd usr/bin ; ln -sf ../../bin/mkdir mkdir )
( cd usr/bin ; rm -rf cat )
( cd usr/bin ; ln -sf ../../bin/cat cat )
( cd usr/bin ; rm -rf fold )
( cd usr/bin ; ln -sf ../../bin/fold fold )
( cd usr/bin ; rm -rf nohup )
( cd usr/bin ; ln -sf ../../bin/nohup nohup )
( cd usr/bin ; rm -rf paste )
( cd usr/bin ; ln -sf ../../bin/paste paste )
( cd usr/bin ; rm -rf base64 )
( cd usr/bin ; ln -sf ../../bin/base64 base64 )
( cd usr/bin ; rm -rf od )
( cd usr/bin ; ln -sf ../../bin/od od )
( cd usr/bin ; rm -rf id )
( cd usr/bin ; ln -sf ../../bin/id id )
( cd usr/bin ; rm -rf stdbuf )
( cd usr/bin ; ln -sf ../../bin/stdbuf stdbuf )
( cd usr/bin ; rm -rf sha384sum )
( cd usr/bin ; ln -sf ../../bin/sha384sum sha384sum )
( cd usr/bin ; rm -rf ptx )
( cd usr/bin ; ln -sf ../../bin/ptx ptx )
( cd usr/bin ; rm -rf comm )
( cd usr/bin ; ln -sf ../../bin/comm comm )
( cd usr/bin ; rm -rf wc )
( cd usr/bin ; ln -sf ../../bin/wc wc )
( cd usr/bin ; rm -rf sha512sum )
( cd usr/bin ; ln -sf ../../bin/sha512sum sha512sum )
( cd usr/bin ; rm -rf ln )
( cd usr/bin ; ln -sf ../../bin/ln ln )
( cd usr/bin ; rm -rf tac )
( cd usr/bin ; ln -sf ../../bin/tac tac )
( cd usr/bin ; rm -rf nice )
( cd usr/bin ; ln -sf ../../bin/nice nice )
( cd usr/bin ; rm -rf link )
( cd usr/bin ; ln -sf ../../bin/link link )
( cd usr/bin ; rm -rf sort )
( cd usr/bin ; ln -sf ../../bin/sort sort )
( cd usr/bin ; rm -rf df )
( cd usr/bin ; ln -sf ../../bin/df df )
( cd usr/bin ; rm -rf timeout )
( cd usr/bin ; ln -sf ../../bin/timeout timeout )
( cd usr/bin ; rm -rf who )
( cd usr/bin ; ln -sf ../../bin/who who )
( cd usr/bin ; rm -rf tr )
( cd usr/bin ; ln -sf ../../bin/tr tr )
( cd usr/bin ; rm -rf env )
( cd usr/bin ; ln -sf ../../bin/env env )
( cd usr/bin ; rm -rf tail )
( cd usr/bin ; ln -sf ../../bin/tail tail )
( cd usr/bin ; rm -rf sync )
( cd usr/bin ; ln -sf ../../bin/sync sync )
( cd usr/bin ; rm -rf sleep )
( cd usr/bin ; ln -sf ../../bin/sleep sleep )
( cd usr/bin ; rm -rf ginstall )
( cd usr/bin ; ln -sf ../../bin/ginstall ginstall )
( cd usr/bin ; rm -rf unexpand )
( cd usr/bin ; ln -sf ../../bin/unexpand unexpand )
( cd usr/bin ; rm -rf mktemp-gnu )
( cd usr/bin ; ln -sf ../../bin/mktemp-gnu mktemp-gnu )
( cd usr/bin ; rm -rf sum )
( cd usr/bin ; ln -sf ../../bin/sum sum )
( cd usr/bin ; rm -rf stty )
( cd usr/bin ; ln -sf ../../bin/stty stty )
( cd usr/bin ; rm -rf shred )
( cd usr/bin ; ln -sf ../../bin/shred shred )
( cd usr/bin ; rm -rf tsort )
( cd usr/bin ; ln -sf ../../bin/tsort tsort )
( cd usr/bin ; rm -rf groups )
( cd usr/bin ; ln -sf ../../bin/groups groups )
( cd usr/bin ; rm -rf whoami )
( cd usr/bin ; ln -sf ../../bin/whoami whoami )
( cd usr/bin ; rm -rf dircolors )
( cd usr/bin ; ln -sf ../../bin/dircolors dircolors )
( cd usr/bin ; rm -rf dd )
( cd usr/bin ; ln -sf ../../bin/dd dd )
( cd usr/bin ; rm -rf tty )
( cd usr/bin ; ln -sf ../../bin/tty tty )
( cd usr/bin ; rm -rf mknod )
( cd usr/bin ; ln -sf ../../bin/mknod mknod )
( cd usr/bin ; rm -rf dirname )
( cd usr/bin ; ln -sf ../../bin/dirname dirname )
( cd usr/bin ; rm -rf mv )
( cd usr/bin ; ln -sf ../../bin/mv mv )
( cd bin ; rm -rf ginstall )
( cd bin ; ln -sf install ginstall )
